@@ -959,7 +959,6 @@ end
 creatures.night_creature.nightmare.default=function(tok)
     local lines={}
     local options={
-        can_bogey_polymorph=true,
         spheres={
             NIGHT=true,
             NIGHTMARES=true,
@@ -2124,7 +2123,9 @@ creatures.angel.humanoid_warrior.default=function(tok)
     add_body_size(lines,math.max(rcp.min_size,50000+trandom(4)*10000+trandom(11)*1000),options)
     lines[#lines+1]="[CREATURE_TILE:"..((options.body_size<=60000) and "132]" or "142]") -- ä or Ä
     options.custom_desc_func=function(options)
-        local add_tbl=pick_random_conditional(sphere_flavor,function(sphere) return options.spheres[sphere] end)
+        local add_tbl=sphere_flavor[pick_random_conditional_pairs(sphere_flavor,function(sphere,_,options) 
+            return options.spheres[sphere] 
+        end,options)]
         if not add_tbl then add_tbl={add="it is a divine being"} end
         if add_tbl.odor then
             options.always_odor=true
@@ -2195,7 +2196,9 @@ creatures.angel.humanoid_generic.default=function(tok)
     add_body_size(lines,math.max(rcp.min_size,50000+trandom(4)*10000+trandom(11)*1000),options)
     lines[#lines+1]="[CREATURE_TILE:"..((options.body_size<=60000) and "132]" or "142]") -- ä or Ä
     options.custom_desc_func=function(options)
-        local add_tbl=pick_random_conditional(sphere_flavor,function(sphere) return options.spheres[sphere] end)
+        local add_tbl=sphere_flavor[pick_random_conditional_pairs(sphere_flavor,function(sphere,_,options) 
+            return options.spheres[sphere] 
+        end,options)]
         if not add_tbl then add_tbl={add="it is a divine being"} end
         if add_tbl.odor then
             options.always_odor=true
@@ -2259,7 +2262,9 @@ creatures.angel.great_beast.default=function(tok)
     add_body_size(lines,math.max(rcp.min_size,10000000),options)
     lines[#lines+1]="[CREATURE_TILE:"..((options.body_size<=60000) and "132]" or "142]") -- ä or Ä
     options.custom_desc_func=function(options)
-        local add_tbl=pick_random_conditional(sphere_flavor,function(sphere) return options.spheres[sphere] end)
+        local add_tbl=sphere_flavor[pick_random_conditional_pairs(sphere_flavor,function(sphere,_,options) 
+            return options.spheres[sphere] 
+        end,options)]
         if not add_tbl then add_tbl={add="it is a divine being"} end
         if add_tbl.odor then
             options.always_odor=true
