@@ -363,10 +363,10 @@ enum AnnouncementType
 	ANNOUNCEMENT_DAWN_BREAKS,
 	ANNOUNCEMENT_NOON,
 	ANNOUNCEMENT_NIGHTFALL,
-	ANNOUNCEMENT_NO_INV_INTERACTION,
+	ANNOUNCEMENT_UNUSED_0001,//
 	ANNOUNCEMENT_EMPTY_CONTAINER,
 	ANNOUNCEMENT_TAKE_OUT_OF_CONTAINER,
-	ANNOUNCEMENT_NO_CONTAINER_FOR_ITEM,
+	ANNOUNCEMENT_UNUSED_0002,//
 	ANNOUNCEMENT_PUT_INTO_CONTAINER,
 	ANNOUNCEMENT_EAT_ITEM,
 	ANNOUNCEMENT_DRINK_ITEM,
@@ -489,7 +489,9 @@ enum AnnouncementType
 	ANNOUNCEMENT_SATISFIED_MONARCH,
 	ANNOUNCEMENT_MOUNTAINHOME,
 	ANNOUNCEMENT_FOOD_WARNING,
-	ANNOUNCEMENT_UNUSED_46,
+	ANNOUNCEMENT_PUT_ON_ITEM,
+	ANNOUNCEMENT_TAKE_OFF_ITEM,
+	ANNOUNCEMENT_DEITY_PRONOUNCEMENT,
 	ANNOUNCEMENT_UNUSED_47,
 	ANNOUNCEMENT_UNUSED_48,
 	ANNOUNCEMENT_UNUSED_49,
